@@ -325,6 +325,11 @@ class BaseCRUDView(BaseView):
     label_columns = {}
     description_columns = {}
     
+    add_form_extra_fields = {}
+    """ Add extra fields to the Add form using this property """
+    edit_form_extra_fields = {}
+    """ Add extra fields to the Edit form using this property """
+    
     page_size = 30
 
     
@@ -377,16 +382,19 @@ class BaseCRUDView(BaseView):
             self.add_form = conv.create_form(self.label_columns,
                     self.description_columns,
                     self.validators_columns,
+                    self.add_form_extra_fields,
                     self.add_columns)
         if not self.edit_form:
             self.edit_form = conv.create_form(self.label_columns,
                     self.description_columns,
                     self.validators_columns,
-                    self.edit_columns)        
+                    self.edit_form_extra_fields,
+                    self.edit_columns)
         if not self.search_form:
             self.search_form = conv.create_form(self.label_columns,
                     self.description_columns,
                     self.validators_columns,
+                    [],
                     self.search_columns)
 
     def _init_titles(self):
@@ -481,6 +489,7 @@ class BaseCRUDView(BaseView):
     def _get_search_widget(self, form = None, exclude_cols = [], widgets = {}):
         widgets['search'] = self.search_widget(route_base = self.route_base,
                                                 form = form,
+                                                include_cols = self.search_columns,
                                                 exclude_cols = exclude_cols,
                                                 )
         return widgets
@@ -505,6 +514,7 @@ class BaseCRUDView(BaseView):
     def _get_add_widget(self, form = None, exclude_cols = [], widgets = {}):
         widgets['add'] = self.edit_widget(route_base = self.route_base,
                                                 form = form,
+                                                include_cols = self.add_columns,
                                                 exclude_cols = exclude_cols,
                                                 fieldsets = self.add_fieldsets
                                                 )
@@ -513,13 +523,13 @@ class BaseCRUDView(BaseView):
     def _get_edit_widget(self, form = None, exclude_cols = [], widgets = {}):
         widgets['edit'] = self.edit_widget(route_base = self.route_base,
                                                 form = form,
+                                                include_cols = self.edit_columns,
                                                 exclude_cols = exclude_cols,
                                                 fieldsets = self.edit_fieldsets
                                                 )
         return widgets
 
 
-
     def debug(self):
 
         print self.__class__.__name__, "SHOW FS", self.show_fieldsets
@@ -676,12 +686,10 @@ class GeneralView(BaseCRUDView):
             return redirect(self._get_redirect())
         else:
             widgets = self._get_add_widget(form = form, exclude_cols = exclude_cols)
-            return render_template(
-                                                    self.add_template,
-                                                    title = self.add_title,
-                                                    widgets = widgets,
-                                                    baseapp = self.baseapp
-                                                    )    
+            return render_template(self.add_template,
+                                   title = self.add_title,
+                                   widgets = widgets,
+                                   baseapp = self.baseapp)    
 
     """
     ---------------------------
